Changelog
=========

Notable changes between releases.

0.4.0 (2016-12-12)
------------------

* Update for Django 1.10
* Drop support for Python 2.6 and Django 1.6 and 1.7

0.3 (2014-12-18)
----------------

* Fix bug in which encoded characters were re-encoded upon redirection
* Add explicit test coverage for Django 1.6 and 1.7 and Python 2.6 to 3.4
* Require Django >= 1.5

0.2 (2013-12-18)
----------------

* Initial release